==> php81-nextcloud-28.0.6.tgz: share/nextcloud/apps/viewer/l10n/eu.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Ikustailea",
    "Simple file viewer with slideshow for media" : "Fitxategi ikustaile sinplea multimediarako diaporama batekin",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Erakutsi zure azken oporretako argazki eta bideoak pelikuletan bezala, erakutsi zure azken nobelaren lagin bat zuzenean zure nextclouden, aukeratu zure bildumako GIFik onena gogoko fitxategien zuzeneko aurrebistari esker, eta gehiago!",
    "Your browser does not support audio." : "Zure nabigatzaileak ez du audioa onartzen.",
    "Error loading {name}" : "Errorea {name} kargatzean",
    "Image saved" : "Irudia gordeta",
    "Error saving image" : "Errorea irudia gordetzean",
    "Unsaved changes" : "Gorde gabeko aldaketak",
    "Drop changes" : "Jaregin aldaketak",
    "LIVE" : "ZUZENEAN",
    "Your browser does not support videos." : "Zure nabigatzaileak ez ditu bideoak onartzen.",
    "Edit" : "Aldatu",
    "Exit full screen" : "Irten pantaila osotik",
    "Full screen" : "Pantaila osoa",
    "Open sidebar" : "Ireki albo-barra",
    "Download" : "Deskargatu",
    "Delete" : "Ezabatu",
    "This file no longer exists" : "Fitxategi hori ez da existitzen",
    "There is no plugin available to display this file type" : "Ez dago plugin erabilgarririk fitxategi mota hau bistaratzeko",
    "View" : "Ikusi",
    "Name" : "Izena",
    "Save" : "Gorde",
    "Save as" : "Gorde honela",
    "Back" : "Atzera",
    "Loading …" : "Kargatzen …",
    "Reset" : "Berrezarri",
    "All changes will be lost." : "Aldaketa guztiak galduko dira.",
    "Are you sure you want to continue?" : "Ziur zaude jarraitu nahi duzula?",
    "Cancel" : "Utzi",
    "Continue" : "Jarraitu",
    "Undo" : "Desegin",
    "Redo" : "Berregin",
    "Show original image" : "Erakutsi jatorrizko irudia",
    "Zoom in" : "Hurbildu",
    "Zoom out" : "Txikiagotu",
    "Toggle zoom menu" : "Aldatu zoom menua",
    "Adjust" : "Egokitu",
    "Fine-tune" : "Doitu",
    "Filters" : "Iragazkiak",
    "Watermark" : "Ur-marka",
    "Draw" : "Margotu",
    "Resize" : "Tamaina aldatu",
    "Invalid image." : "Irudi baliogabea.",
    "Error while uploading the image." : "Errorea irudia igotzean.",
    "are not images" : "ez da irudirik",
    "is not an image" : "ez da irudi bat",
    "to be uploaded" : "igotzeko",
    "Crop" : "Moztu",
    "Original" : "Jatorrizkoa",
    "Custom" : "Pertsonalizatua",
    "Square" : "Karratua",
    "Landscape" : "Paisaia",
    "Portrait" : "Erretratua",
    "Ellipse" : "Elipsea",
    "Classic TV" : "Telebista klasikoa",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Gezia",
    "Blur" : "Lausotu",
    "Brightness" : "Distira",
    "Contrast" : "Kontrastea",
    "Un-flip X" : "Desegin X irauli",
    "Flip X" : "Irauli X",
    "Un-flip Y" : "Desegin Y irauli",
    "Flip Y" : "Irauli Y",
    "HSV" : "HSV",
    "Hue" : "Ñabardura",
    "Saturation" : "Saturazioa",
    "Value" : "Balioa",
    "Image" : "Irudia",
    "Importing …" : "Inportatzen ...",
    "+ Add image" : "+ Gehitu irudia",
    "Line" : "Lerro",
    "Pen" : "Boligrafoa",
    "Polygon" : "Poligonoa",
    "Sides" : "Aldeak",
    "Rectangle" : "Laukizuzena",
    "Corner Radius" : "Izkinako erradioa",
    "Width in pixels" : "Zabalera pixeletan",
    "Height in pixels" : "Altuera pixeletan",
    "Toggle ratio lock" : "Etengabeko erlazioaren blokeoa",
    "Reset to original image size" : "Berrezarri jatorrizko irudiaren tamainara",
    "Rotate" : "Biratu",
    "Text" : "Testua",
    "Text spacing" : "Testu-tarteak",
    "Text alignment" : "Testuaren lerrokatzea",
    "Font family" : "Letra-tipoen familia",
    "Size" : "Tamaina",
    "Letter spacing" : "Letren tartea",
    "Line height" : "Lerroaren altuera",
    "Warmth" : "Epeltasuna",
    "+ Add watermark" : "+ Gehitu ur-marka",
    "Choose watermark type" : "Aukeratu ur-marka mota",
    "Upload watermark" : "Igo ur-marka",
    "Add as text" : "Gehitu testu gisa",
    "Padding" : "Betegarria",
    "Shadow" : "Itzala",
    "Horizontal" : "Horizontala",
    "Vertical" : "Bertikala",
    "Opacity" : "Opakotasuna",
    "Position" : "Kokalekua",
    "Stroke" : "Trazua",
    "Save image as" : "Gorde irudia honela:",
    "Extension" : "Hedapena",
    "Name is required." : "Izena beharrezkoa da",
    "Quality" : "Kalitatea",
    "Saved image size (width x height)" : "Gordetako irudiaren tamaina (zabalera x altuera)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Kontuan izan hautatutako mozte-eremua aplikatutako tamaina baino txikiagoa dela eta horrek kalitatea gutxitzea eragin dezakeela",
    "Actual size (100%)" : "Benetako tamaina (% 100)",
    "Fit size" : "Egokitu tamaina",
    "\"{fileName}\"" : "\"{fileName}\""
},
"nplurals=2; plural=(n != 1);");

==> php81-nextcloud-30.0.5.tgz: share/nextcloud/apps/viewer/l10n/eu.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Ikustailea",
    "Simple file viewer with slideshow for media" : "Fitxategi ikustaile sinplea multimediarako diaporama batekin",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Erakutsi zure azken oporretako argazki eta bideoak pelikuletan bezala, erakutsi zure azken nobelaren lagin bat zuzenean zure nextclouden, aukeratu zure bildumako GIFik onena gogoko fitxategien zuzeneko aurrebistari esker, eta gehiago!",
    "Your browser does not support audio." : "Zure nabigatzaileak ez du audioa onartzen.",
    "Error loading {name}" : "Errorea {name} kargatzean",
    "Image saved" : "Irudia gordeta",
    "Error saving image" : "Errorea irudia gordetzean",
    "Unsaved changes" : "Gorde gabeko aldaketak",
    "Drop changes" : "Jaregin aldaketak",
    "Play the live photo" : "Erreproduzitu zuzeneko argazkia",
    "LIVE" : "ZUZENEAN",
    "Your browser does not support videos." : "Zure nabigatzaileak ez ditu bideoak onartzen.",
    "Edit" : "Aldatu",
    "Exit full screen" : "Irten pantaila osotik",
    "Full screen" : "Pantaila osoa",
    "Open sidebar" : "Ireki albo-barra",
    "Download" : "Deskargatu",
    "Delete" : "Ezabatu",
    "This file no longer exists" : "Fitxategi hori ez da existitzen",
    "There is no plugin available to display this file type" : "Ez dago plugin erabilgarririk fitxategi mota hau bistaratzeko",
    "View" : "Ikusi",
    "Name" : "Izena",
    "Save" : "Gorde",
    "Save as" : "Gorde honela",
    "Back" : "Atzera",
    "Loading …" : "Kargatzen …",
    "Reset" : "Berrezarri",
    "All changes will be lost." : "Aldaketa guztiak galduko dira.",
    "Are you sure you want to continue?" : "Ziur zaude jarraitu nahi duzula?",
    "Cancel" : "Utzi",
    "Apply" : "Aplikatu",
    "Warning" : "Abisua",
    "Confirm" : "Berretsi",
    "Discard changes" : "Baztertu aldaketak",
    "Undo" : "Desegin",
    "Redo" : "Berregin",
    "Show original image" : "Erakutsi jatorrizko irudia",
    "Zoom in" : "Hurbildu",
    "Zoom out" : "Txikiagotu",
    "Toggle zoom menu" : "Aldatu zoom menua",
    "Adjust" : "Egokitu",
    "Fine-tune" : "Doitu",
    "Filters" : "Iragazkiak",
    "Watermark" : "Ur-marka",
    "Draw" : "Margotu",
    "Resize" : "Tamaina aldatu",
    "Image name" : "Irudiaren izena",
    "Invalid image." : "Irudi baliogabea.",
    "Error while uploading the image." : "Errorea irudia igotzean.",
    "are not images" : "ez da irudirik",
    "is not an image" : "ez da irudi bat",
    "to be uploaded" : "igotzeko",
    "Crop" : "Moztu",
    "Original" : "Jatorrizkoa",
    "Custom" : "Pertsonalizatua",
    "Square" : "Karratua",
    "Landscape" : "Paisaia",
    "Portrait" : "Erretratua",
    "Ellipse" : "Elipsea",
    "Classic TV" : "Telebista klasikoa",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Gezia",
    "Blur" : "Lausotu",
    "Brightness" : "Distira",
    "Contrast" : "Kontrastea",
    "Un-flip X" : "Desegin X irauli",
    "Flip X" : "Irauli X",
    "Un-flip Y" : "Desegin Y irauli",
    "Flip Y" : "Irauli Y",
    "HSV" : "HSV",
    "Hue" : "Ñabardura",
    "Saturation" : "Saturazioa",
    "Value" : "Balioa",
    "Image" : "Irudia",
    "Importing …" : "Inportatzen ...",
    "+ Add image" : "+ Gehitu irudia",
    "Upload image" : "Igo irudia",
    "From gallery" : "Galeriatik",
    "Line" : "Lerro",
    "Pen" : "Boligrafoa",
    "Polygon" : "Poligonoa",
    "Sides" : "Aldeak",
    "Rectangle" : "Laukizuzena",
    "Corner Radius" : "Izkinako erradioa",
    "Width in pixels" : "Zabalera pixeletan",
    "Height in pixels" : "Altuera pixeletan",
    "Toggle ratio lock" : "Etengabeko erlazioaren blokeoa",
    "Reset to original image size" : "Berrezarri jatorrizko irudiaren tamainara",
    "Rotate" : "Biratu",
    "Text" : "Testua",
    "Text spacing" : "Testu-tarteak",
    "Text alignment" : "Testuaren lerrokatzea",
    "Font family" : "Letra-tipoen familia",
    "Size" : "Tamaina",
    "Letter spacing" : "Letren tartea",
    "Line height" : "Lerroaren altuera",
    "Warmth" : "Epeltasuna",
    "+ Add watermark" : "+ Gehitu ur-marka",
    "+ Add text watermark" : "+ Gehitu testu ur-marka",
    "Choose watermark type" : "Aukeratu ur-marka mota",
    "Upload watermark" : "Igo ur-marka",
    "Add as text" : "Gehitu testu gisa",
    "Padding" : "Betegarria",
    "Paddings" : "Betegarriak",
    "Shadow" : "Itzala",
    "Horizontal" : "Horizontala",
    "Vertical" : "Bertikala",
    "Opacity" : "Opakotasuna",
    "Transparency" : "Gardentasuna",
    "Position" : "Kokalekua",
    "Stroke" : "Trazua",
    "Save image as" : "Gorde irudia honela:",
    "Extension" : "Hedapena",
    "Format" : "Formatua",
    "Name is required." : "Izena beharrezkoa da",
    "Quality" : "Kalitatea",
    "Saved image size (width x height)" : "Gordetako irudiaren tamaina (zabalera x altuera)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Kontuan izan hautatutako mozte-eremua aplikatutako tamaina baino txikiagoa dela eta horrek kalitatea gutxitzea eragin dezakeela",
    "Actual size (100%)" : "Benetako tamaina (% 100)",
    "Fit size" : "Egokitu tamaina",
    "Select image to add …" : "Hautatu gehitzeko irudia ...",
    "Failed to load image." : "Irudia kargatzeak huts egin du.",
    "Menu" : "Menua",
    "Width" : "Zabalera",
    "Height" : "Altuera",
    "No preview available for this crop item" : "Ez dago aurreikuspenik eskuragarri ebakitako elementu honentzat"
},
"nplurals=2; plural=(n != 1);");
